@@ -22,6 +22,6 @@ from ..__version__ import __version__
 def analyze(
     ctx: click.Context,
 ) -> Union[str, int, None]:
-    """Analyzes Robot Framework Tests."""
+    """Analyzes a Robot Framework project."""
     click.echo("Not implemented yet")
     return 0
